@@ -1,8 +1,7 @@
- /*
+/*
 
     Copyright (c) 2013 by Pali Rohár <pali.rohar@gmail.com>
 
-
     *************************************************************************
     *                                                                       *
     * This program is free software; you can redistribute it and/or modify  *
@@ -20,16 +19,16 @@
 
 class JabberBoBCache : public XMPP::BoBCache
 {
-	Q_OBJECT
+    Q_OBJECT
 
 public:
-	JabberBoBCache(QObject *parent = NULL);
+    JabberBoBCache(QObject *parent = NULL);
 
-	virtual void put(const XMPP::BoBData &data);
-	virtual XMPP::BoBData get(const QString &cid);
+    void put(const XMPP::BoBData &data) Q_DECL_OVERRIDE;
+    XMPP::BoBData get(const QString &cid) Q_DECL_OVERRIDE;
 
 private:
-	QHash <QString, XMPP::BoBData> mem;
+    QHash <QString, XMPP::BoBData> mem;
 };
 
 #endif
