@@ -144,7 +144,7 @@ namespace XMPP
 		BasicProtocol();
 		~BasicProtocol();
 
-		void reset();
+		void reset() override;
 
 		// for outgoing xml
 		QDomDocument doc;
@@ -199,17 +199,17 @@ namespace XMPP
 		void delayError(int code);
 
 		// reimplemented
-		QDomElement docElement();
-		void handleDocOpen(const Parser::Event &pe);
-		bool handleError();
-		bool handleCloseFinished();
-		bool doStep(const QDomElement &e);
-		void itemWritten(int id, int size);
+		QDomElement docElement() override;
+		void handleDocOpen(const Parser::Event &pe) override;
+		bool handleError() override;
+		bool handleCloseFinished() override;
+		bool doStep(const QDomElement &e) override;
+		void itemWritten(int id, int size) override;
 
 		virtual QString defaultNamespace();
-		virtual QStringList extraNamespaces(); // stringlist: prefix,uri,prefix,uri, [...]
+		virtual QStringList extraNamespaces() ; // stringlist: prefix,uri,prefix,uri, [...]
 		virtual void handleStreamOpen(const Parser::Event &pe);
-		virtual bool doStep2(const QDomElement &e)=0;
+		virtual bool doStep2(const QDomElement &e) = 0;
 
 		void setReady(bool b);
 
@@ -262,7 +262,7 @@ namespace XMPP
 		CoreProtocol();
 		~CoreProtocol();
 
-		void reset();
+		void reset() override;
 		void startTimer(int seconds);
 
 		// reimplemented to do SM
@@ -363,16 +363,16 @@ namespace XMPP
 		bool needSMRequest();
 
 		// reimplemented
-		bool stepAdvancesParser() const;
-		bool stepRequiresElement() const;
-		void stringSend(const QString &s);
-		void stringRecv(const QString &s);
-		QString defaultNamespace();
-		QStringList extraNamespaces();
-		void handleStreamOpen(const Parser::Event &pe);
-		bool doStep2(const QDomElement &e);
-		void elementSend(const QDomElement &e);
-		void elementRecv(const QDomElement &e);
+		bool stepAdvancesParser() const override;
+		bool stepRequiresElement() const override;
+		void stringSend(const QString &s) override;
+		void stringRecv(const QString &s) override;
+		QString defaultNamespace() override;
+		QStringList extraNamespaces() override;
+		void handleStreamOpen(const Parser::Event &pe) override;
+		bool doStep2(const QDomElement &e) override;
+		void elementSend(const QDomElement &e) override;
+		void elementRecv(const QDomElement &e) override;
 	};
 }
 
